@@ -134,22 +134,19 @@ class PrerequisiteValidator(AmdTool):
         if len(edids) == 0:
             self.db.record_debug("No EDID data found")
             return True
-
         for name, p in edids.items():
             output = None
-            for cmd in ["di-edid-decode", "edid-decode"]:
+            for tool in ["di-edid-decode", "edid-decode"]:
                 try:
-                    cmd = ["edid-decode", p]
+                    cmd = [tool, p]
                     output = subprocess.check_output(
                         cmd, stderr=subprocess.DEVNULL
-                    ).decode("utf-8")
+                    ).decode("utf-8", errors="ignore")
                     break
                 except FileNotFoundError:
                     self.db.record_debug(f"{cmd} not installed")
                 except subprocess.CalledProcessError as e:
-                    self.db.record_debug(
-                        f"failed to capture edid with {cmd}: {e.output}"
-                    )
+                    pass
             if not output:
                 self.db.record_prereq("Failed to capture EDID table", "👀")
             else:
@@ -245,7 +242,6 @@ class PrerequisiteValidator(AmdTool):
         for dev in self.pyudev.list_devices(subsystem="pci", DRIVER="nvme"):
             # https://git.kernel.org/torvalds/c/e79a10652bbd3
             if minimum_kernel(6, 10):
-                self.db.record_debug("New enough kernel to avoid NVME check")
                 break
             pci_slot_name = dev.properties["PCI_SLOT_NAME"]
             vendor = dev.properties.get("ID_VENDOR_FROM_DATABASE", "")
@@ -319,7 +315,6 @@ class PrerequisiteValidator(AmdTool):
         # not needed to check in newer kernels
         # see https://github.com/torvalds/linux/commit/77f1972bdcf7513293e8bbe376b9fe837310ee9c
         if minimum_kernel(6, 10):
-            self.db.record_debug("New enough kernel to avoid HSMP check")
             return True
         f = os.path.join("/", "boot", f"config-{platform.uname().release}")
         if os.path.exists(f):
@@ -527,7 +522,7 @@ class PrerequisiteValidator(AmdTool):
                 f"{keys['sys_vendor']} {keys['product_name']} ({keys['product_family']})",
                 "💻",
             )
-            debug_str = "DMI data:\n"
+            debug_str = "DMI|value\n"
             for key, value in keys.items():
                 if (
                     "product_name" in key
@@ -535,7 +530,7 @@ class PrerequisiteValidator(AmdTool):
                     or "product_family" in key
                 ):
                     continue
-                debug_str += f"{key}: {value}\n"
+                debug_str += f"{key}| {value}\n"
             self.db.record_debug(debug_str)
         return True
 
@@ -916,7 +911,7 @@ class PrerequisiteValidator(AmdTool):
         devices = []
         for dev in self.pyudev.list_devices(subsystem="pci"):
             devices.append(dev)
-        debug_str = "PCI devices\n"
+        debug_str = "PCI Slot | Vendor | Class | ID | ACPI path\n"
         for dev in devices:
             pci_id = dev.properties["PCI_ID"].lower()
             pci_slot_name = dev.properties["PCI_SLOT_NAME"]
@@ -939,15 +934,12 @@ class PrerequisiteValidator(AmdTool):
             p = os.path.join(dev.sys_path, "firmware_node", "path")
             if os.path.exists(p):
                 acpi = read_file(p)
-                debug_str += (
-                    f"{prefix}{pci_slot_name} : "
-                    f"{database_vendor} {database_class} [{pci_id}] : {acpi}\n"
-                )
             else:
-                debug_str += (
-                    f"{prefix}{pci_slot_name} : "
-                    f"{database_vendor} {database_class} [{pci_id}]\n"
-                )
+                acpi = ""
+            debug_str += (
+                f"{prefix}{pci_slot_name} | "
+                f"{database_vendor} | {database_class} | {pci_id} | {acpi}\n"
+            )
         if debug_str:
             self.db.record_debug(debug_str)
 
@@ -964,12 +956,8 @@ class PrerequisiteValidator(AmdTool):
                 if status == 0:
                     continue
             devices.append(dev)
-        debug_str = "ACPI name: ACPI path [driver]\n"
+        debug_str = "ACPI name | ACPI path | Kernel driver\n"
         for dev in devices:
-            if dev == devices[-1]:
-                prefix = "└─"
-            else:
-                prefix = "│ "
             p = os.path.join(dev.sys_path, "path")
             pth = read_file(p)
             p = os.path.join(dev.sys_path, "physical_node", "driver")
@@ -977,7 +965,7 @@ class PrerequisiteValidator(AmdTool):
                 driver = os.path.basename(os.readlink(p))
             else:
                 driver = None
-            debug_str += f"{prefix}{dev.sys_name}: {pth} [{driver}]\n"
+            debug_str += f"{dev.sys_name} | {pth} | {driver}\n"
         if debug_str:
             self.db.record_debug(debug_str)
         return True
@@ -1157,7 +1145,6 @@ class PrerequisiteValidator(AmdTool):
             if not found_iommu:
                 self.db.record_prereq("IOMMU disabled", "✅")
                 return True
-            debug_str += "DMA protection:\n"
             p = os.path.join("/", "sys", "firmware", "acpi", "tables", "IVRS")
             with open(p, "rb") as f:
                 data = f.read()
